H5_file_name = '/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317-.h5'
label_key = 'labels'



from PSM_testbed.WhACC.touch_curation_GUI import touch_gui

touch_gui(H5_file_name, label_key)
